@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from collective.volto.subsites.interfaces import IVoltoSubsitesSettings
 from design.plone.contenttypes.controlpanels.settings import (
     IDesignPloneSettings,
 )
@@ -17,7 +18,11 @@ import json
 class HiddenProfiles(object):
     def getNonInstallableProfiles(self):
         """Hide uninstall profile from site-creation and quickinstaller."""
-        return ["design.plone.policy:uninstall", "design.plone.policy:to_1400"]
+        return [
+            "design.plone.policy:uninstall",
+            "design.plone.policy:test",
+            "design.plone.policy:to_1400",
+        ]
 
 
 def post_install(context):
@@ -34,12 +39,13 @@ def post_install(context):
     folderSubstructureGenerator(
         title="Documenti e dati",
         types=(
-            "Document",
-            "Image",
-            "File",
-            "Link",
-            "Documento",
+            "Bando",
             "CartellaModulistica",
+            "Document",
+            "Documento",
+            "File",
+            "Image",
+            "Link",
         ),
     )
     folderSubstructureGenerator(
@@ -62,6 +68,7 @@ def post_install(context):
     )
 
     disable_searchable_types()
+    set_default_subsite_colors()
 
 
 def disable_searchable_types():
@@ -85,6 +92,30 @@ def disable_searchable_types():
     settings.types_not_searched = tuple(types)
 
 
+def set_default_subsite_colors():
+    colors = [
+        "white",
+        "yellow",
+        "magenta",
+        "teal",
+        "light-yellow",
+        "light-pink",
+        "light-teal",
+        "light-blue",
+    ]
+    old = api.portal.get_registry_record(
+        "available_styles", interface=IVoltoSubsitesSettings, default=[]
+    )
+
+    for color in colors:
+        if color not in old:
+            old.append(color)
+
+    api.portal.set_registry_record(
+        "available_styles", sorted(old), interface=IVoltoSubsitesSettings
+    )
+
+
 def uninstall(context):
     """Uninstall script"""
     # Do something at the end of the uninstallation of this package.
