@@ -8,6 +8,7 @@ from plone.app.testing import PloneSandboxLayer
 from plone.app.testing import quickInstallProduct
 from plone.restapi.testing import PloneRestApiDXLayer
 from plone.testing import z2
+from zope.globalrequest import setRequest
 
 import collective.folderishtypes
 import collective.MockMailHost
@@ -28,6 +29,10 @@ import redturtle.volto
 import redturtle.voltoplugin.editablefooter
 
 
+class FauxRequest(dict):
+    URL = "http://nohost"
+
+
 class DesignPlonePolicyLayer(PloneSandboxLayer):
 
     defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)
@@ -55,6 +60,8 @@ class DesignPlonePolicyLayer(PloneSandboxLayer):
         self.loadZCML(package=redturtle.voltoplugin.editablefooter)
 
     def setUpPloneSite(self, portal):
+        request = FauxRequest()
+        setRequest(request)
         applyProfile(portal, "plone.app.caching:default")
         applyProfile(portal, "design.plone.policy:default")
 
@@ -112,6 +119,8 @@ class DesignPlonePolicyRestApiLayer(PloneRestApiDXLayer):
         self.loadZCML(package=redturtle.voltoplugin.editablefooter)
 
     def setUpPloneSite(self, portal):
+        request = FauxRequest()
+        setRequest(request)
         applyProfile(portal, "plone.app.caching:default")
         applyProfile(portal, "design.plone.policy:default")
         quickInstallProduct(portal, "collective.MockMailHost")
